#
# spec file for package mozilla-jss
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mozilla-jss
Summary:        Java Security Services (JSS)
License:        GPL-2.0-only OR MPL-1.1 OR LGPL-2.1-only
Group:          Development/Libraries/Java
URL:            http://www.dogtagpki.org/wiki/JSS
Version:        5.0.0
Release:        3.3
Source0:        https://github.com/dogtagpki/jss/archive/v%{version}/jss-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  git
BuildRequires:  make
BuildRequires:  unzip
BuildRequires:  zip

BuildRequires:  apache-commons-lang3
BuildRequires:  gcc-c++
BuildRequires:  java-devel
BuildRequires:  jpackage-utils
BuildRequires:  libfreebl3-hmac
BuildRequires:  libsoftokn3-hmac
BuildRequires:  mozilla-nspr-devel >= 4.13.1
BuildRequires:  mozilla-nss-devel >= 3.44
BuildRequires:  mozilla-nss-sysinit >= 3.44
BuildRequires:  mozilla-nss-tools >= 3.44
BuildRequires:  slf4j
BuildRequires:  slf4j-jdk14

BuildRequires:  junit

Requires:       apache-commons-lang3
Requires:       java-headless
Requires:       jpackage-utils
Requires:       mozilla-nss >= 3.44
Requires:       slf4j
Requires:       slf4j-jdk14

Conflicts:      idm-console-framework < 1.2
Conflicts:      ldapjdk < 4.20
Conflicts:      pki-base < 10.6.5
Conflicts:      tomcatjss < 7.3.4

%description
Java Security Services (JSS) is a java native interface which provides a bridge
for java-based applications to use native Network Security Services (NSS).
This only works with gcj. Other JREs require that JCE providers be signed.

%package javadoc

Summary:        Java Security Services (JSS) Javadocs
Group:          Development/Libraries/Java
Requires:       mozilla-jss = %{version}

%description javadoc
This package contains the API documentation for JSS.

%prep
%autosetup -n jss-%{version}

%build
%set_build_flags
export JAVA_HOME=%{java_home}

# Enable compiler optimizations
export BUILD_OPT=1

# Generate symbolic info for debuggers
CFLAGS="-g $RPM_OPT_FLAGS"
export CFLAGS

# Check if we're in FIPS mode
modutil -dbdir /etc/pki/nssdb -chkfips true | grep -q enabled && export FIPS_ENABLED=1

./build.sh \
    %{?_verbose:-v} \
    --work-dir=%{_vpath_builddir} \
    --java-lib-dir=%{_jnidir} \
    --jss-lib-dir=%{_libdir}/jss \
    --version=%{version} \
    %{!?with_javadoc:--without-javadoc} \
    %{!?with_test:--without-test} \
    dist

%install

./build.sh \
    %{?_verbose:-v} \
    --work-dir=%{_vpath_builddir} \
    --install-dir=%{buildroot} \
    install

%files

%defattr(-,root,root,-)
%doc jss.html
%license MPL-1.1.txt gpl.txt lgpl.txt
%{_libdir}/jss
%{_jnidir}/*

%if %{with javadoc}

%files javadoc

%defattr(-,root,root,-)
%{_javadocdir}/%{name}/
%endif

%changelog
* Fri Sep 29 2023 Fridrich Strba <fstrba@suse.com>
- Remove bogus runtime dependency on apache-commons-lang
* Tue Mar  1 2022 Andreas Schwab <schwab@suse.de>
- Don't package /usr/lib/debug
* Sun Jan  2 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to 5.0.0
- Drop BuildRequires and Requires on glassfish-jaxb-api
* Fri Jun  5 2020 Stasiek Michalski <stasiek@michalski.cc>
- Fix debuginfo detection on i586
* Tue Apr 14 2020 Stasiek Michalski <stasiek@michalski.cc>
- Update to 4.6.3
- Remove patches:
  * jss-4.5.0-slf4j.patch
  * jss-4.5.0-deprecation-warnings.patch
  * jss-4.5.0-pkcs11-constants.patch
  * jss-4.5.0-nojavah.patch
  * jss-4.5.0-sourcetarget.patch
- Ship with licenses included with the source instead of adding our own
* Sat Nov 10 2018 schwab@suse.de
- Define USE_64 for riscv64
* Thu Sep 20 2018 Fridrich Strba <fstrba@suse.com>
- Update to jss 4.5.0
- Added patches:
  * jss-4.5.0-slf4j.patch
    + Use the right name of slf4j's api.jar
  * jss-4.5.0-deprecation-warnings.patch
    + Address most deprecation warnings
  * jss-4.5.0-pkcs11-constants.patch
    + Address problem with PKCS11 constants no longer being
    visible in latest JDKs
  * jss-4.5.0-nojavah.patch
    + Changes to generate JNI header files the new way.
    + Fixes build on jdk10 and further
  * jss-4.5.0-sourcetarget.patch
    + Build with source and target 8 to avoid compatibility issues
* Thu Apr 19 2018 guillaume.gardet@opensuse.org
- Update to jss 4.4.3
- Remove upstreamed patches:
  * jss-4.3.2-support-TLS1_1-TLS1_2.patch
  * jss-ipv6.patch
* Fri Apr 10 2015 aj@ajaissle.de
- Switch sources to new SCM, see:
  * https://hg.mozilla.org/projects/jss/
- Added jss-4.3.2-support-TLS1_1-TLS1_2.patch:
  + Adds support for SSLVersionRange
  + Adds TLS 1.1 + TLS 1.2 ciphersuites
  * Requires mozilla-nss >= 3.15.1
- Rename license files, update whitespaces
  * gpl.txt -> GPL-2.0.txt
  * lgpl.txt -> LGPL-2.1.txt
- Spec cleanup, license cleanup, reserving Patch0001-Patch0026
  for Debian and Fedora patches (see
  https://anonscm.debian.org/cgit/pkg-fedora-ds/jss.git/tree/debian/patches/series)
* Sun May 11 2014 aj@ajaissle.de
- Fixed build on SLES with kernels > 2.x
- Replaced '$RPM_BUILD_ROOT' with '%%{buildroot}
- Removed %%cleanup section
* Sun Sep  8 2013 wr@rosenauer.org
- fixed build in Factory by making /usr/lib/java and
  /usr/share/javadoc part of the package
* Thu Jul 11 2013 aj@ajaissle.de
- Add copyright header
* Sun Dec  9 2012 aj@ajaissle.de
- Fixed spec to work with openSUSE >= 12.2 (autoget kernel version)
* Mon Mar  5 2012 wr@rosenauer.org
- fixed build for Linux >= 3
* Mon Apr 11 2011 wr@rosenauer.org
- initial openSUSE package
